aind\_behavior\_curriculum.curriculum.BehaviorGraph
===================================================

.. currentmodule:: aind_behavior_curriculum.curriculum

.. autoclass:: BehaviorGraph
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~BehaviorGraph.__init__
      ~BehaviorGraph.add_node
      ~BehaviorGraph.add_transition
      ~BehaviorGraph.construct
      ~BehaviorGraph.copy
      ~BehaviorGraph.dict
      ~BehaviorGraph.from_orm
      ~BehaviorGraph.json
      ~BehaviorGraph.model_construct
      ~BehaviorGraph.model_copy
      ~BehaviorGraph.model_dump
      ~BehaviorGraph.model_dump_json
      ~BehaviorGraph.model_json_schema
      ~BehaviorGraph.model_parametrized_name
      ~BehaviorGraph.model_post_init
      ~BehaviorGraph.model_rebuild
      ~BehaviorGraph.model_validate
      ~BehaviorGraph.model_validate_json
      ~BehaviorGraph.model_validate_strings
      ~BehaviorGraph.parse_file
      ~BehaviorGraph.parse_obj
      ~BehaviorGraph.parse_raw
      ~BehaviorGraph.remove_node
      ~BehaviorGraph.remove_node_transition
      ~BehaviorGraph.schema
      ~BehaviorGraph.schema_json
      ~BehaviorGraph.see_node_transitions
      ~BehaviorGraph.see_nodes
      ~BehaviorGraph.set_transition_priority
      ~BehaviorGraph.update_forward_refs
      ~BehaviorGraph.validate
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~BehaviorGraph.model_computed_fields
      ~BehaviorGraph.model_config
      ~BehaviorGraph.model_extra
      ~BehaviorGraph.model_fields
      ~BehaviorGraph.model_fields_set
      ~BehaviorGraph.nodes
      ~BehaviorGraph.graph
   
   